@@ -387,6 +387,40 @@ Bayonne::Handler Bayonne::getState(const char *id)
 	}
 	return (Handler)NULL;
 }
+
+Audio::Encoding Bayonne::getEncoding(const char *cp)
+{
+	const char *encoding = cp;
+
+	if(*encoding == '.')
+		++encoding;
+	
+        if(!strnicmp(encoding, "g.", 2))
+                encoding += 2;
+        else if(encoding[0] == 'g' && isdigit(encoding[1]))
+                ++encoding;
+
+        if(!stricmp(encoding, "stereo"))
+                return Audio::pcm16Stereo;
+        if(!stricmp(encoding, "726-40") || !stricmp(encoding, "a40"))
+                return Audio::g723_5bit;
+        if(!stricmp(encoding, "726-32") || !stricmp(encoding, "a32"))
+                return Audio::g721ADPCM;
+        if(!stricmp(encoding, "726-24") || !stricmp(encoding, "a24"))
+                return Audio::g723_3bit;
+        if(!stricmp(encoding, "726-16") || !stricmp(encoding, "a16"))
+                return Audio::g723_2bit;
+        if(!stricmp(encoding, "729"))
+                return Audio::g729Audio;
+        if(!stricmp(encoding, "721"))
+                return Audio::g721ADPCM;
+        if(!stricmp(encoding, "pcmu"))
+                return Audio::mulawAudio;
+        if(!stricmp(encoding, "pcma"))
+                return Audio::alawAudio;
+
+	return Audio::getEncoding(cp);
+}
 	
 bool Bayonne::matchDigits(const char *digits, const char *match, bool partial)
 {
