@@ -271,7 +271,7 @@ Assoc()
 		cp = ".a24";
 	else if(!stricmp(cp, "a16"))
 		cp = ".a16";
-	info.encoding = getEncoding(cp);
+	info.encoding = Bayonne::getEncoding(cp);
 	info.rate = rate8khz;
 	cp = getLast("rate");
 	if(cp)
@@ -2550,10 +2550,21 @@ killit:
                         if(session->dtmf_payload)
                         {
                                 snprintf(cbuf, sizeof(cbuf),
-                                        "a=rtpmap:%d telephone-events/8000\r\n",                                        
+                                        "a=rtpmap:%d telephone-event/8000\r\n"
+					"a=fmtp:%d 0-15\r\n",                                        
+					session->dtmf_payload,
 					session->dtmf_payload);
                                 addString(sdp, 4096, cbuf);
                         }
+			data_rtpmap = Session::getAttributes(session->info.encoding);
+			if(data_rtpmap)
+			{
+				snprintf(cbuf, sizeof(cbuf),
+					"a=fmtp:%d %s\r\n",
+					session->data_payload,
+					data_rtpmap);
+				addString(sdp, 4096, cbuf);
+			}
 			memset(&event, 0, sizeof(event));
 			if(*conn->c_addr == '0' || inactive)
 				event.id = CALL_HOLD;
@@ -3095,15 +3106,26 @@ sip415:
 			if(session->dtmf_payload)
 			{
 				snprintf(cbuf, sizeof(cbuf),
-					"a=rtpmap:%d telephone-events/8000",
+					"a=rtpmap:%d telephone-event/8000",
 					session->dtmf_payload);
 				session->setConst("session.sdp_events", cbuf);
 				snprintf(cbuf, sizeof(cbuf),
-					"a=rtpmap:%d telephone-events/8000\r\n",
+					"a=rtpmap:%d telephone-event/8000\r\n"
+					"a=fmtp:%d 0-15\r\n",
+					session->dtmf_payload,
 					session->dtmf_payload);
 				addString(sdp, 4096, cbuf);
 			}
 
+			data_rtpmap = Session::getAttributes(session->info.encoding);
+			if(data_rtpmap)
+			{
+				snprintf(cbuf, sizeof(cbuf),
+					"a=fmtp:%d %s\r\n",
+					session->data_payload, data_rtpmap);
+				addString(sdp, 4096, cbuf);
+			}
+
                         if(!s->postEvent(&event))
                                 goto sip404;
 
