@@ -44,6 +44,7 @@ TimerPort()
 	encoding_recall = NULL;
 	peer_buffer = NULL;
 	peer_codec = NULL;
+	codec = NULL;
 	session_timer = 0;
 	sv = 0;
 }
@@ -137,6 +138,17 @@ const char *Session::audioEncoding(void)
 	}
 }
 
+const char *Session::getAttributes(Audio::Encoding enc)
+{
+	switch(enc)
+	{
+	case g729Audio:
+		return "annexb=no";
+	default:
+		return NULL;
+	}
+}
+
 const char *Session::sdpEncoding(void)
 {
 	switch(info.encoding)
@@ -219,9 +231,11 @@ void Session::redirect(const char *target, const char *encoding, unsigned char d
 	osip_message_t *msg = NULL;
 	char sdp[512];
 	char addr[65];
+	char cbuf[65];
 	char *ep;
 	unsigned port;
 	const char *invite = "";
+	const char *cp;
 
 	setString(addr, sizeof(addr), target);
 	ep = strrchr(addr, ':');
@@ -250,9 +264,10 @@ void Session::redirect(const char *target, const char *encoding, unsigned char d
 			"t=0 0\r\n"
 			"m=audio %d RTP/AVP %d %d\r\n"
 			"a=rtpmap:%d %s\r\n"
-			"a=rtpmap:%d telephone-events/8000\r\n%s",
+			"a=rtpmap:%d telephone-event/8000\r\n"
+			"a=fmtp:%d 0-15\r\n",
 			++sv, addr, addr, port, data, dtmf,
-			data, encoding, dtmf, invite);
+			data, encoding, dtmf, dtmf);
 	else
 		snprintf(sdp, sizeof(sdp),
 			"v=0\r\n"
@@ -261,8 +276,20 @@ void Session::redirect(const char *target, const char *encoding, unsigned char d
 			"c=IN IP4 %s\r\n"
 			"t=0 0\r\n"
 			"m=audio %d RTP/AVP %d\r\n"
-			"a=rtpmap:%d %s\r\n%s",
-			++sv, addr, addr, port, data, data, encoding, invite);
+			"a=rtpmap:%d %s\r\n",
+			++sv, addr, addr, port, data, data, encoding);
+
+	cp = getAttributes(Bayonne::getEncoding(encoding));
+	if(cp)
+	{
+		snprintf(cbuf, sizeof(cbuf),
+			"a=fmtp:%d %s\r\n",
+			data, cp);
+		addString(sdp, sizeof(sdp), cbuf);
+	}
+
+	if(invite)
+		addString(sdp, sizeof(sdp), invite);
 	
 	osip_message_set_body(msg, sdp, strlen(sdp));
 	osip_message_set_content_type(msg, "application/sdp");
@@ -375,18 +402,7 @@ void Session::setEncoding(const char *encoding, timeout_t framing)
 
 	memset(&info, 0, sizeof(info));
 
-	if(!stricmp(encoding, "stereo"))
-		info.encoding = Audio::pcm16Stereo;
-	else if(!stricmp(encoding, "g726-40") || !stricmp(encoding, "a40"))
-		info.encoding = Audio::g723_5bit;
-	else if(!stricmp(encoding, "g726-24") || !stricmp(encoding, "a24"))
-		info.encoding = Audio::g723_3bit;
-	else if(!stricmp(encoding, "g726-16") || !stricmp(encoding, "a16"))
-		info.encoding = Audio::g723_2bit;
-	else if(!stricmp(encoding, "a32"))
-		info.encoding = Audio::g721ADPCM;
-	else
-		info.encoding = Audio::getEncoding(encoding);
+	info.encoding = Bayonne::getEncoding(encoding);
 
 	switch(info.encoding)
 	{
@@ -1001,7 +1017,7 @@ failure:
 		if(dtmf_payload)
 		{
 			snprintf(sdp, sizeof(sdp),
-				"a=rtpmap:%d telephone-events/8000",
+				"a=rtpmap:%d telephone-event/8000",
 				dtmf_payload);
 			setConst("session.sdp_events", sdp);
                         snprintf(sdp, sizeof(sdp),
@@ -1012,10 +1028,11 @@ failure:
                                 "t=0 0\r\n"
                                 "m=audio %d RTP/AVP %d %d\r\n"
                                 "%s\r\n"
-				"a=rtpmap:%d telephone-events/8000\r\n",
+				"a=rtpmap:%d telephone-event/8000\r\n"
+				"a=fmtp:%d 0-15\r\n",
 				cp, cp, 
 				getLocalPort(), data_payload, dtmf_payload,
-				rtpmap, dtmf_payload);
+				rtpmap, dtmf_payload, dtmf_payload);
 		}
 		else
 			snprintf(sdp, sizeof(sdp),
@@ -1030,6 +1047,15 @@ failure:
 				getLocalPort(), data_payload, 
 				rtpmap);
 
+		cp = getAttributes(info.encoding);
+		if(cp)
+		{
+			snprintf(cbuf, sizeof(cbuf),
+				"a=fmtp:%d %s\r\n",
+				data_payload, cp);
+			addString(sdp, sizeof(sdp), cbuf);
+		}
+
 		setConst("session.sdp_encoding", rtpmap);
 		if(reg && reg->peering)
 			setPeering(reg->peering);
